﻿Type=Class
Version=2.52
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private m_Width As Int 'store the drawing surface width
	Private m_Height As Int 'store the drawing surface height
	Private m_Scale As Float 'store the current scale between JWorld and our Screen
	Private m_LeftStart As Float 'there exists a point that is the marker for the World object left
	Private m_TopStart As Float 'ditto for top edge
	Private m_BottomStart As Float 'for tracking bottom edge in the JWorld
	Private OneMeter As Float 'how many pixels represent one meter in JWorld
	Private m_OriginalHeightInMeters 'to remember original Scale for all future changes
	Private m_CurrentHeightInMeters 
	
End Sub

'Pass the display surface width and height, and initial Height In Meters that your surface represents
'Default for LeftEdge of surface is 0x in the JBox2DWorld
'Default for TopEdge is the DisplayHeightInMeters (i.e. bottom edge is 0y, top edge is DisplayHeightInMeters)
'This will also represent Scale of 1, all further changes to Scale will shift these coordinates appropriately
Public Sub Initialize(DisplaySurfaceWidth As Int, DisplaySurfaceHeight As Int, DisplayHeightInMeters As Float )
m_Width = DisplaySurfaceWidth
m_Height = DisplaySurfaceHeight
m_BottomStart = 0
OneMeter = m_Height/DisplayHeightInMeters
m_LeftStart = 0
m_TopStart = DisplayHeightInMeters
m_OriginalHeightInMeters = DisplayHeightInMeters 
m_CurrentHeightInMeters = DisplayHeightInMeters
m_Scale = 1

End Sub

'sets Display Window to the new Height
'if SetAsNewScale is True, then also used as new reference Scale
'otherwise, Scale is adjusted based on new Height
'left edge is kept the same, and bottom edge is kept the same
Public Sub SetHeightInMeters(newHeightInMeters As Float, SetAsNewScale As Boolean)

	If SetAsNewScale Then
		m_CurrentHeightInMeters = newHeightInMeters
		m_TopStart = m_BottomStart + newHeightInMeters
		OneMeter = m_Height/newHeightInMeters
		m_OriginalHeightInMeters = newheightinmeters
		m_Scale = 1
	Else
		m_CurrentHeightInMeters = newHeightInMeters
		m_TopStart = m_BottomStart + newHeightInMeters
		m_Scale = m_OriginalHeightInMeters/newHeightInMeters
		OneMeter = m_Height/newHeightInMeters
	End If

End Sub

'transform World jbVec2 to Display jbVec2
Public Sub ChangeWorldVecToDisplayVec(worldVec As jbVec2) As jbVec2
Dim newVec As jbVec2
newVec.x = (worldVec.x - m_LeftStart) * OneMeter
newVec.y = (m_TopStart - worldVec.y) * OneMeter
Return newVec
End Sub

'transform Display jbVec2 to World jbVec2
Public Sub ChangeDisplayVecToWorldVec(displayVec As jbVec2) As jbVec2
Dim newVec As jbVec2
newVec.x = m_LeftStart + displayVec.x/OneMeter 
newVec.y = m_TopStart - displayVec.y/OneMeter

Return newVec	

End Sub

'based on original Scale Size, change the scale of Dislay vs JWorld
'Bigger than 1 means Zoom in (i.e. 3 would make everthing 3 times larger on the screen)
'If ScaleOnCenter is false, current LeftEdge and BottomEdge remain the same
'If True, centerpoint stays the same, and all other World Coordinates shift
Public Sub ChangeScale(newScale As Float, ScaleOnCenter As Boolean)

m_Scale = newScale



If ScaleOnCenter Then
	'need to keep coming in center point the same and all others move
	Dim currentCenterX, currentCenterY As Float
	currentCenterX = m_LeftStart + m_Width/OneMeter * .5
	currentCenterY = m_BottomStart + (m_TopStart - m_BottomStart)/2
	m_CurrentHeightInMeters = m_OriginalHeightInMeters/m_Scale
	OneMeter =	m_Height/(m_OriginalHeightInMeters/m_Scale)
	
	SetCenterPoint(currentCenterX, currentCenterY)
	
Else
	m_TopStart = m_BottomStart + (m_OriginalHeightInMeters/m_Scale)
End If

OneMeter =	m_Height/(m_OriginalHeightInMeters/m_Scale)
End Sub


'Centers current display around Given JWorld x,y based on current scale
Public Sub SetCenterPoint(x As Float, y As Float)
	m_TopStart = y + m_CurrentHeightInMeters*.5
	m_BottomStart = y - m_CurrentHeightInMeters*.5
	m_LeftStart = x - m_Width/OneMeter * .5
End Sub

'Sets Display to start at given JWorld X Coordinate
Public Sub SetLeftEdge(x As Float)
	m_LeftStart = x
End Sub

'set Display Bottom Edge to given JWorld Y Coordinate
Public Sub setBottomEdge(y As Float)
	m_BottomStart = y
	m_TopStart = m_CurrentHeightInMeters + m_BottomStart
End Sub

'convert Length in JWorld to Display Length
Public Sub JWorldLengthToDisplayLength(worldLength As Float) As Float

Return (worldLength * OneMeter)

End Sub



'centers and scales Display image on two JWorld points such that both
'points will appear on screen, with centerpoint between them set
'as the center point between them
Public Sub CenterAndScaleOnTwoPoints(x1 As Float, y1 As Float, x2 As Float, y2 As Float)



End Sub

'returns current display Height in JWorld Meters
Public Sub getCurrentHeightInMeters As Float
	Return m_CurrentHeightInMeters
End Sub

'return current display width in JWorld Meters
Public Sub getCurrentWidthInMeters As Float
	Return m_Width/OneMeter
End Sub

'returns current right Edge of JWorld X coordinate
Public Sub GetRightEdge As Float
Return m_LeftStart + m_Width * OneMeter
End Sub

'return the World Coordinates from Display Coordinates
Public Sub GetWorldPointFromDisplay(displayPoint As jbVec2) As jbVec2
Dim newvec As jbVec2
	newvec.Initialize(m_LeftStart + displayPoint.x/OneMeter, m_TopStart - displayPoint.y/OneMeter)
Return newvec
End Sub

'given a JWorld Width, and a DisplayWidth (in Pixels) adjusts scale to match
'current centerpoint is retained
Public Sub ScaleToFit(JWorldWidth As Float, DesiredDisplayWidth As Float)


End Sub

'returns current Display Scale relative to original set scale
Public Sub getCurrentScale As Float
	Return m_Scale
End Sub

